@@ -1,5 +1,5 @@
 package Heap::Simple::Hash;
-$VERSION = "0.01";
+$VERSION = "0.02";
 use strict;
 use Carp;
 
@@ -21,6 +21,8 @@ sub _KEY {
 
 sub min_key {
     my $self = shift;
+    croak "min_key not supported (no infinity) on ", ref($self) unless
+        $self->can("_INF");
     $self->_make('sub {
         my $self = shift;
     return @$self > 1 ? $self->[1]{$self->[0][2]} : _INF()
